@@ -1,3 +1,7 @@
+# Part of Spatial Math Toolbox for Python
+# Copyright (c) 2000 Peter Corke
+# MIT Licence, see details in top-level file: LICENCE
+
 from spatialmath.base.argcheck import *
 from spatialmath.base.quaternions import *
 from spatialmath.base.transforms2d import *
@@ -5,6 +9,7 @@ from spatialmath.base.transforms3d import *
 from spatialmath.base.transformsNd import *
 from spatialmath.base.vectors import *
 from spatialmath.base.symbolic import *
+from spatialmath.base.animate import *
 
 __all__ = [
 # spatialmath.base.argcheck
@@ -89,7 +94,7 @@ __all__ = [
     'r2t',
     'tr2rt',
     'rt2tr',
-    'rt2m',
+    'Ab2M',
     'isR',
     'isskew',
     'isskewa',
@@ -101,7 +106,9 @@ __all__ = [
     'h2e',
     'e2h',
     'homtrans',
+    'rodrigues',
 # spatialmath.base.vectors
+    'colvec',
     'unitvec',
     'norm',
     'isunitvec',
@@ -112,5 +119,8 @@ __all__ = [
     'unittwist_norm',
     'unittwist2',
     'angdiff',
-    'removesmall'
+    'removesmall',
+# spatialmath.base.animate
+    'Animate',
+    'Animate2',
  ]
