@@ -1,10 +1,7 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
-"""
-Created on Mon Apr 27 12:44:45 2020
+# Part of Spatial Math Toolbox for Python
+# Copyright (c) 2000 Peter Corke
+# MIT Licence, see details in top-level file: LICENCE
 
-@author: corkep
-"""
 # matplotlib inline
 
 # line.set_data()
@@ -15,8 +12,7 @@ Created on Mon Apr 27 12:44:45 2020
 import numpy as np
 import matplotlib.pyplot as plt
 from matplotlib import animation
-
-from spatialmath import base as tr
+from spatialmath import base
 
 
 class Animate:
@@ -52,7 +48,7 @@ class Animate:
         :param dims: dimension of plot volume as [xmin, xmax, ymin, ymax,
             zmin, zmax]. If dims is [min, max] those limits are applied
             to the x-, y- and z-axes.
-        :type dims: array_like
+        :type dims: array_like(6) or array_like(2)
         :param projection: 3D projection: ortho [default] or persp
         :type projection: str
         :param labels: labels for the axes, defaults to X, Y and Z
@@ -96,10 +92,10 @@ class Animate:
         """
         Define the transform to animate
 
-        :param end: the final pose SO(3) or SE(3) to display as a coordinate frame
-        :type end: numpy.ndarray, shape=(3,3) or (4,4)
-        :param start: the initial pose SO(3) or SE(3) to display as a coordinate frame, defaults to null
-        :type start: numpy.ndarray, shape=(3,3) or (4,4)
+        :param end: the final pose SE(3) or SO(3) to display as a coordinate frame
+        :type end: ndarray(4,4) or ndarray(3,3)
+        :param start: the initial pose SE(3) or SO(3) to display as a coordinate frame, defaults to null
+        :type start: ndarray(4,4) or ndarray(3,3)
         :param start: an 
 
         Is polymorphic with ``base.trplot`` and accepts the same parameters.
@@ -109,21 +105,21 @@ class Animate:
 
         """
         # stash the final value
-        if tr.isrot(end):
-            self.end = tr.r2t(end)
+        if base.isrot(end):
+            self.end = base.r2t(end)
         else:
             self.end = end
 
         if start is None:
             self.start = np.identity(4)
         else:
-            if tr.isrot(start):
-                self.start = tr.r2t(start)
+            if base.isrot(start):
+                self.start = base.r2t(start)
             else:
                 self.start = start
 
         # draw axes at the origin
-        tr.trplot(self.start, axes=self, block=None, **kwargs)
+        base.trplot(self.start, axes=self, block=None, **kwargs)
 
     def run(self, movie=None, axes=None, repeat=False, interval=50, nframes=100, pause=0, **kwargs):
         """
@@ -143,15 +139,15 @@ class Animate:
         Animates a 3D coordinate frame moving from the world frame to a frame
         represented by the SO(3) or SE(3) matrix to the current axes.
 
-        Notes:
+        .. note::
 
-        - the ``movie`` option requires the ffmpeg package to be installed:
-            ``conda install -c conda-forge ffmpeg``
-        - invokes the draw() method of every object in the display list
+            - the ``movie`` option requires the ffmpeg package to be installed:
+              ``conda install -c conda-forge ffmpeg``
+            - invokes the draw() method of every object in the display list
         """
 
         def update(frame, a):
-            T = tr.trinterp(start=self.start, end=self.end, s=frame / nframes)
+            T = base.trinterp(start=self.start, end=self.end, s=frame / nframes)
             a._draw(T)
             if frame == nframes - 1:
                 a.done = True
@@ -322,13 +318,15 @@ class Animate:
         :param x: x-coordinate
         :type x: float
         :param y: float
-        :type y: array_like
+        :type y: float
         :param z: z-coordinate
         :type z: float
+        :param kwargs: Other arguments as accepted by the matplotlib method.
 
-        Other arguments as accepted by the matplotlib method.
+        ``.text(x, y, z, s)`` display the string ``s`` at coordinate 
+        (``x``, ``y``, ``z``).
 
-        :seealso: :func:`matplotlib.pyplot.text`
+        :seealso: :func:`~matplotlib.pyplot.text`
         """
         h = self.ax.text3D(x, y, z, *args, **kwargs)
         self.displaylist.append(Animate._Text(self, h, x, y, z))
@@ -389,10 +387,9 @@ class Animate2:
 
         :param axes: the axes to plot into, defaults to current axes
         :type axes: Axes3D reference
-        :param dims: dimension of plot volume as [xmin, xmax, ymin, ymax,
-            zmin, zmax]. If dims is [min, max] those limits are applied
-            to the x-, y- and z-axes.
-        :type dims: array_like
+        :param dims: dimension of plot volume as [xmin, xmax, ymin, ymax]. If 
+            dims is [min, max] those limits are applied to the x- and y-axes.
+        :type dims: array_like(4) or array_like(2)
         :param projection: 3D projection: ortho [default] or persp
         :type projection: str
         :param labels: labels for the axes, defaults to X, Y and Z
@@ -431,10 +428,10 @@ class Animate2:
         """
         Define the transform to animate
 
-        :param end: the final pose SO(2) or SE(2) to display as a coordinate frame
-        :type end: numpy.ndarray, shape=(2,2) or (3,3)
-        :param start: the initial pose SO(2) or SE(2) to display as a coordinate frame, defaults to null
-        :type start: numpy.ndarray, shape=(2,2) or (3,3)
+        :param end: the final pose SE(2) or SO(2) to display as a coordinate frame
+        :type end: ndarray(3,3) or ndarray(2,2)
+        :param start: the initial pose SE(2) or SO(2) to display as a coordinate frame, defaults to null
+        :type start: ndarray(3,3) or ndarray(2,2)
 
         Is polymorphic with ``base.trplot`` and accepts the same parameters.
         This sets up the animation but doesn't execute it.
@@ -443,21 +440,21 @@ class Animate2:
 
         """
         # stash the final value
-        if tr.isrot2(end):
-            self.end = tr.r2t(end)
+        if base.isrot2(end):
+            self.end = base.r2t(end)
         else:
             self.end = end
 
         if start is None:
             self.start = np.identity(3)
         else:
-            if tr.isrot2(start):
-                self.start = tr.r2t(start)
+            if base.isrot2(start):
+                self.start = base.r2t(start)
             else:
                 self.start = start
 
         # draw axes at the origin
-        tr.trplot2(self.start, axes=self, block=False, **kwargs)
+        base.trplot2(self.start, axes=self, block=False, **kwargs)
 
     def run(self, movie=None, axes=None, repeat=False, interval=50, nframes=100, **kwargs):
         """
@@ -477,15 +474,15 @@ class Animate2:
         Animates a 3D coordinate frame moving from the world frame to a frame
         represented by the SO(3) or SE(3) matrix to the current axes.
 
-        Notes:
+        .. note::
 
-        - the ``movie`` option requires the ffmpeg package to be installed:
-            ``conda install -c conda-forge ffmpeg``
-        - invokes the draw() method of every object in the display list
+            - the ``movie`` option requires the ffmpeg package to be installed:
+              ``conda install -c conda-forge ffmpeg``
+            - invokes the draw() method of every object in the display list
         """
 
         def update(frame, a):
-            T = tr.trinterp2(start=self.start, end=self.end, s=frame / nframes)
+            T = base.trinterp2(start=self.start, end=self.end, s=frame / nframes)
             a._draw(T)
             if frame == nframes - 1:
                 a.done = True
@@ -582,7 +579,7 @@ class Animate2:
             self.p = np.c_[u - x, v - y].T
 
         def draw(self, T):
-            R, t = tr.tr2rt(T)
+            R, t = base.tr2rt(T)
             p = R @ self.p
             # specific to a single Quiver
             self.h.set_offsets(t)  # shift the origin
@@ -637,11 +634,13 @@ class Animate2:
         :param x: x-coordinate
         :type x: float
         :param y: float
-        :type y: array_like
+        :type y: float
         :param z: z-coordinate
         :type z: float
+        :param kwargs: Other arguments as accepted by the matplotlib method.
 
-        Other arguments as accepted by the matplotlib method.
+        ``.text(x, y, s)`` display the string ``s`` at coordinate 
+        (``x``, ``y``).
 
         :seealso: :func:`matplotlib.pyplot.text`
         """
