@@ -1,49 +1,19 @@
+# Part of Spatial Math Toolbox for Python
+# Copyright (c) 2000 Peter Corke
+# MIT Licence, see details in top-level file: LICENCE
+
 """
-This modules contains functions to create and transform rotation matrices
-and homogeneous tranformation matrices.
+Functions to manipulate vectors
 
 Vector arguments are what numpy refers to as ``array_like`` and can be a list,
 tuple, numpy array, numpy row vector or numpy column vector.
-
 """
 
-# This file is part of the SpatialMath toolbox for Python
-# https://github.com/petercorke/spatialmath-python
-#
-# MIT License
-#
-# Copyright (c) 1993-2020 Peter Corke
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-
-# Contributors:
-#
-#     1. Luis Fernando Lara Tobar and Peter Corke, 2008
-#     2. Josh Carrigg Hodson, Aditya Dua, Chee Ho Chan, 2017 (robopy)
-#     3. Peter Corke, 2020
-
 # pylint: disable=invalid-name
 
 import math
 import numpy as np
-from spatialmath.base import argcheck
-
+from spatialmath.base import getvector
 
 _eps = np.finfo(np.float64).eps
 
@@ -52,32 +22,44 @@ def colvec(v):
     """
     Create a column vector
 
-    :param v: an N-vector
-    :type v: array like
+    :param v: any vector
+    :type v: array_like(n)
     :return: a column vector
-    :rtype: NumPy ndarray, shape=(N,1)
+    :rtype: ndarray(n,1)
+
+    Convert input to a column vector.
+
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import *
+        >>> colvec([1, 2, 3])
     """
+    v = getvector(v)
     return np.array(v).reshape((len(v), 1))
 
 
-# ---------------------------------------------------------------------------------------#
 def unitvec(v):
     """
     Create a unit vector
 
-    :param v: n-dimensional vector
-    :type v: array_like
-    :return: a unit-vector parallel to V.
-    :rtype: numpy.ndarray
+    :param v: any vector
+    :type v: array_like(n)
+    :return: a unit-vector parallel to ``v``.
+    :rtype: ndarray(n)
     :raises ValueError: for zero length vector
 
     ``unitvec(v)`` is a vector parallel to `v` of unit length.
 
-    :seealso: norm
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import *
+        >>> unitvec([3, 4])
+
+    :seealso: :func:`~numpy.linalg.norm`
 
     """
 
-    v = argcheck.getvector(v)
+    v = getvector(v)
     n = np.linalg.norm(v)
 
     if n > 100 * _eps:  # if greater than eps
@@ -90,13 +72,19 @@ def norm(v):
     """
     Norm of vector
 
-    :param v: n-vector as a list, dict, or a numpy array, row or column vector
+    :param v: any vector
+    :type v: array_like(n)
     :return: norm of vector
     :rtype: float
 
     ``norm(v)`` is the 2-norm (length or magnitude) of the vector ``v``.
 
-    :seealso: unit
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import *
+        >>> norm([3, 4])
+
+    :seealso: :func:`~spatialmath.base.unit`
 
     """
     return np.linalg.norm(v)
@@ -107,12 +95,18 @@ def isunitvec(v, tol=10):
     Test if vector has unit length
 
     :param v: vector to test
-    :type v: numpy.ndarray
+    :type v: ndarray(n)
     :param tol: tolerance in units of eps
     :type tol: float
     :return: whether vector has unit length
     :rtype: bool
 
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import *
+        >>> isunitvec([1, 0])
+        >>> isunitvec([1, 2])
+
     :seealso: unit, isunittwist
     """
     return abs(np.linalg.norm(v) - 1) < tol * _eps
@@ -123,12 +117,18 @@ def iszerovec(v, tol=10):
     Test if vector has zero length
 
     :param v: vector to test
-    :type v: numpy.ndarray
+    :type v: ndarray(n)
     :param tol: tolerance in units of eps
     :type tol: float
     :return: whether vector has zero length
     :rtype: bool
 
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import *
+        >>> isunit([0, 0])
+        >>> isunit([1, 2])
+
     :seealso: unit, isunittwist
     """
     return np.linalg.norm(v) < tol * _eps
@@ -138,12 +138,14 @@ def isunittwist(v, tol=10):
     r"""
     Test if vector represents a unit twist in SE(2) or SE(3)
 
-    :param v: vector to test
-    :type v: array_like
+    :param v: twist vector to test
+    :type v: array_like(6)
     :param tol: tolerance in units of eps
     :type tol: float
-    :return: whether vector has unit length
+    :return: whether twist has unit length
     :rtype: bool
+    :raises ValueError: for incorrect vector length
+
 
     Vector is is intepretted as :math:`[v, \omega]` where :math:`v \in \mathbb{R}^n` and
     :math:`\omega \in \mathbb{R}^1` for SE(2) and :math:`\omega \in \mathbb{R}^3` for SE(3).
@@ -153,15 +155,19 @@ def isunittwist(v, tol=10):
     - unit rotational twist where :math:`|| \omega || = 1`, or
     - unit translational twist where :math:`|| \omega || = 0` and :math:`|| v || = 1`.
 
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import *
+        >>> isunittwist([1, 2, 3, 1, 0, 0])
+        >>> isunittwist([0, 0, 0, 2, 0, 0])
+
     :seealso: unit, isunitvec
     """
-    v = argcheck.getvector(v)
+    v = getvector(v)
 
     if len(v) == 6:
         # test for SE(3) twist
         return isunitvec(v[3:6], tol=tol) or (np.linalg.norm(v[3:6]) < tol * _eps and isunitvec(v[0:3], tol=tol))
-    elif len(v) == 3:
-        return isunitvec(v[2], tol=tol) or (abs(v[2]) < tol * _eps and isunitvec(v[0:2], tol=tol))
     else:
         raise ValueError
 
@@ -170,12 +176,13 @@ def isunittwist2(v, tol=10):
     r"""
     Test if vector represents a unit twist in SE(2) or SE(3)
 
-    :param v: vector to test
-    :type v: array_like
+    :param v: twist vector to test
+    :type v: array_like(3)
     :param tol: tolerance in units of eps
     :type tol: float
     :return: whether vector has unit length
     :rtype: bool
+    :raises ValueError: for incorrect vector length
 
     Vector is is intepretted as :math:`[v, \omega]` where :math:`v \in \mathbb{R}^n` and
     :math:`\omega \in \mathbb{R}^1` for SE(2) and :math:`\omega \in \mathbb{R}^3` for SE(3).
@@ -185,9 +192,15 @@ def isunittwist2(v, tol=10):
     - unit rotational twist where :math:`|| \omega || = 1`, or
     - unit translational twist where :math:`|| \omega || = 0` and :math:`|| v || = 1`.
 
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import *
+        >>> isunittwist2([1, 2, 1])
+        >>> isunittwist2([0, 0, 2])
+
     :seealso: unit, isunitvec
     """
-    v = argcheck.getvector(v)
+    v = getvector(v)
 
     if len(v) == 3:
         # test for SE(2) twist
@@ -200,22 +213,28 @@ def unittwist(S, tol=10):
     """
     Convert twist to unit twist
 
-    :param S: twist as a 6-vector
-    :type S: array_like
+    :param S: twist vector
+    :type S: array_like(6)
     :param tol: tolerance in units of eps
     :type tol: float
-    :return: unit twist and scalar motion
-    :rtype: np.ndarray, shape=(6,)
+    :return: unit twist
+    :rtype: ndarray(6)
 
     A unit twist is a twist where:
 
     - the rotation part has unit magnitude
     - if the rotational part is zero, then the translational part has unit magnitude
 
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import *
+        >>> unittwist([2, 4, 6, 2, 0, 0])
+        >>> unittwist([2, 0, 0, 0, 0, 0])
+
     Returns None if the twist has zero magnitude
     """
 
-    s = argcheck.getvector(S, 6)
+    s = getvector(S, 6)
 
     if iszerovec(s, tol=tol):
         return None
@@ -235,22 +254,32 @@ def unittwist_norm(S, tol=10):
     """
     Convert twist to unit twist and norm
 
-    :param S: twist as a 6-vector
-    :type S: array_like
+    :param S: twist vector
+    :type S: array_like(6)
     :param tol: tolerance in units of eps
     :type tol: float
     :return: unit twist and scalar motion
-    :rtype: tuple (np.ndarray shape=(6,), theta)
+    :rtype: tuple (ndarray(6), float)
 
     A unit twist is a twist where:
 
     - the rotation part has unit magnitude
     - if the rotational part is zero, then the translational part has unit magnitude
 
-    Returns (None,None) if the twist has zero magnitude
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import *
+        >>> S, n = unittwist_norm([1, 2, 3, 1, 0, 0])
+        >>> print(S, n)
+        >>> S, n = unittwist_norm([0, 0, 0, 2, 0, 0])
+        >>> print(S, n)
+        >>> S, n = unittwist_norm([0, 0, 0, 0, 0, 0])
+        >>> print(S, n)
+
+    .. note:: Returns (None,None) if the twist has zero magnitude
     """
 
-    s = argcheck.getvector(S, 6)
+    s = getvector(S, 6)
 
     if iszerovec(s, tol=tol):
         return (None, None)
@@ -270,18 +299,58 @@ def unittwist2(S):
     """
     Convert twist to unit twist
 
-    :param S: twist as a 3-vector
-    :type S: array_like
-    :return: unit twist and scalar motion
-    :rtype: tuple (unit_twist, theta)
+    :param S: twist vector
+    :type S: array_like(3)
+    :return: unit twist 
+    :rtype: ndarray(3)
 
     A unit twist is a twist where:
 
     - the rotation part has unit magnitude
     - if the rotational part is zero, then the translational part has unit magnitude
+
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import *
+        >>> unittwist2([2, 4, 2)
+        >>> unittwist2([2, 0, 0])
+
     """
 
-    S = argcheck.getvector(S, 3)
+    S = getvector(S, 3)
+    v = S[0:2]
+    w = S[2]
+
+    if iszerovec(w):
+        th = norm(v)
+    else:
+        th = norm(w)
+
+    return S / th
+
+def unittwist2_norm(S):
+    """
+    Convert twist to unit twist
+
+    :param S: twist vector
+    :type S: array_like(3)
+    :return: unit twist and scalar motion
+    :rtype: tuple (ndarray(3), float)
+
+    A unit twist is a twist where:
+
+    - the rotation part has unit magnitude
+    - if the rotational part is zero, then the translational part has unit magnitude
+
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import *
+        >>> unittwist2([2, 4, 2)
+        >>> unittwist2([2, 0, 0])
+
+    """
+
+    S = getvector(S, 3)
     v = S[0:2]
     w = S[2]
 
@@ -292,7 +361,6 @@ def unittwist2(S):
 
     return (S / th, th)
 
-
 def angdiff(a, b):
     """
     Angular difference
@@ -308,6 +376,14 @@ def angdiff(a, b):
     - If ``a`` is array_like, the result is a vector a[i]-b
     - If ``a`` is array_like, the result is a vector a-b[i]
     - If ``a`` and ``b`` are both vectors of the same length, the result is a vector a[i]-b[i]
+
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import *
+        >>> from math import pi
+        >>> angdiff(0, 2 * pi)
+        >>> angdiff(0.9 * pi, -0.9 * pi) / pi
+
     """
 
     return np.mod(a - b + math.pi, 2 * math.pi) - math.pi
@@ -316,14 +392,24 @@ def removesmall(v, tol=100):
     """
     Set small values to zero
 
-    :param v: Input vector
-    :type v: array-like
+    :param v: any vector
+    :type v: array_like(n) or ndarray(n,m)
     :param tol: Tolerance in units of eps, defaults to 100
     :type tol: int, optional
-    :return: Input vector with small values set to zero
-    :rtype: NumPy ndarray
+    :return: vector with small values set to zero
+    :rtype: ndarray(n) or ndarray(n,m)
 
     Values with absolute value less than ``tol`` will be set to zero.
+
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import *
+        >>> a = np.r_[1, 2, 3, 1e-16]
+        >>> print(a)
+        >>> a = removesmall(a)
+        >>> print(a)
+        >>> print(a[3])
+
     """
     return np.where(abs(v) < tol * _eps, 0, v)
 
@@ -331,4 +417,4 @@ def removesmall(v, tol=100):
 if __name__ == '__main__':  # pragma: no cover
     import pathlib
 
-    exec(open(pathlib.Path(__file__).parent.absolute() / "test_argcheck.py").read())  # pylint: disable=exec-used
+    exec(open(pathlib.Path(__file__).parent.absolute() / "test_vectors.py").read())  # pylint: disable=exec-used
