@@ -493,4 +493,4 @@ if __name__ == '__main__':  # pragma: no cover
 
     import pathlib
 
-    exec(open(pathlib.Path(__file__).parent.absolute() / "test_pose2d.py").read())  # pylint: disable=exec-used
+    exec(open(pathlib.Path(__file__).parent.absolute() / "test" / "test_pose2d.py").read())  # pylint: disable=exec-used
